# library

This subpackage contains the code to build the `cellprofiler-library` package. It contains the image processing modules required by the [CellProfiler](https://cellprofiler.org) software. Both the [core](https://github.com/CellProfiler/CellProfiler/tree/main/src/subpackages/core) subpackage, and the [frontend](https://github.com/CellProfiler/CellProfiler/tree/main/src/frontend) rely on this subpackage. This package can be used in isolation, separate from the `cellprofiler` and `cellprofiler-core` packages to access CellProfiler's image processing functionality as a Python package.

It is currently a work under progress, and does not yet contain all or even most of CellProfiler's image processing capabilities.
